### Name: qualityParameters
### Title: Calculation of quality characteristics for cDNA chip
###   hybridisations
### Aliases: qualityParameters


### ** Examples

      spotIdentifierVec <- c("A","A","Blank","B","B","Blank")
      hybNames <- "H1"
      R1 <- N1 <- c(1,1,9,2,2,10)
      R2 <- N2 <- c(2,2,7,4,4,8)
      rawDataIntensities <- array(0, dim=c(6,2,1))
      rawDataIntensities[,1,] <- R1
      rawDataIntensities[,2,] <- R2
      dimnames(rawDataIntensities) <- list(NULL, c("Cy3","Cy5"), NULL)
      spotattr=data.frame(Name=I(spotIdentifierVec))
      hybattr=data.frame(slideNumber=I(hybNames))
      arrayDataObject <- new("arrayData", intensities=rawDataIntensities, hybattr=hybattr, spotattr=spotattr)
      indCy3=1
      indCy5=2
      channels <- matrix( c(indCy3,indCy5), nrow=length(indCy3), byrow=FALSE )
      colnames(channels) <- c("Cy3","Cy5")
      exprSetArrayObject <- new("exprSetArray",         
        exprs=matrix(c(R1,R2), nrow=6, byrow=FALSE), phenoData= 
          new("phenoData", pData=data.frame(matrix(0,nrow=2,ncol=1)),
              varLabels=list(rep("varLabel1",1))), channels=channels)           
      Re1 <- qualityParameters(arrayDataObject=arrayDataObject, exprSetArrayObject=exprSetArrayObject, identifiersToBeSkipped= "Blank")
      stopifnot(all.equal.numeric(as.numeric(Re1$qualityParameters["H1",c("correlation")]),c(1)))
      stopifnot(Re1$replicateSpots==2)
   ## Don't show:
      spotIdentifierVec <- c("Blank","A","A","A","B","B","B")
      R1 <- N1 <- c(10,1,1,1,2,2,2)
      R2 <- N2 <- c(11,2,2,2,4,4,4)
      rawDataIntensities <- array(0, dim=c(7,2,1))
      rawDataIntensities[,1,] <- R1
      rawDataIntensities[,2,] <- R2
      dimnames(rawDataIntensities) <- list(NULL, c("Cy3","Cy5"), NULL)
      spotattr=data.frame(Name=I(spotIdentifierVec))
      hybattr=data.frame(slideNumber=I(hybNames))
      arrayDataObject <- new("arrayData", intensities=rawDataIntensities, hybattr=hybattr, spotattr=spotattr)
      indCy3=1
      indCy5=2
      channels <- matrix( c(indCy3,indCy5), nrow=length(indCy3), byrow=FALSE )
      colnames(channels) <- c("Cy3","Cy5")
      exprSetArrayObject <- new("exprSetArray",         
        exprs=matrix(c(R1,R2), nrow=7, byrow=FALSE), phenoData= 
          new("phenoData", pData=data.frame(matrix(0,nrow=2,ncol=1)),
              varLabels=list(rep("varLabel1",1))), channels=channels)           

      Re2 <- qualityParameters(arrayDataObject=arrayDataObject, exprSetArrayObject=exprSetArrayObject, identifiersToBeSkipped= "Blank")

      stopifnot(all.equal.numeric(as.numeric(Re2$qualityParameters["H1",c("correlation")]),c(1)))
      stopifnot(Re2$replicateSpots==3)

      hybNames <- c("H1","H2")
      Xr1 <- Xn1 <- cbind(R1,R2)
      Xr2 <- Xn2 <- cbind(R2,R1)
      rawDataIntensities <- array(0, dim=c(7,2,2))
      rawDataIntensities[,1,1:2] <- Xr1
      rawDataIntensities[,2,1:2] <- Xr2
      dimnames(rawDataIntensities) <- list(NULL, c("Cy3","Cy5"), NULL)
      spotattr=data.frame(Name=I(spotIdentifierVec))
      hybattr=data.frame(slideNumber=I(hybNames))
      arrayDataObject <- new("arrayData", intensities=rawDataIntensities, hybattr=hybattr, spotattr=spotattr)
      indCy3=1:2
      indCy5=3:4
      channels <- matrix( c(indCy3,indCy5), nrow=length(indCy3), byrow=FALSE )
      colnames(channels) <- c("Cy3","Cy5")
      exprSetArrayObject <- new("exprSetArray",         
        exprs=as.matrix(cbind(Xr1,Xr2)), phenoData=     
          new("phenoData", pData=data.frame(matrix(0,nrow=4,ncol=1)),
              varLabels=list(rep("varLabel1",1))), channels=channels)           

      Re3 <- qualityParameters(arrayDataObject=arrayDataObject, exprSetArrayObject=exprSetArrayObject, identifiersToBeSkipped= "Blank")

      stopifnot(all.equal.numeric(as.numeric(Re3$qualityParameters["H2",c("correlation")]),c(1)))
      stopifnot(Re3$replicateSpots==3)
   ## End Don't show

        


